# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDataStorageFilesCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'partition_value': 'str',
        'sub_partition_values': 'list[str]',
        'business_object_data_version': 'int',
        'storage_name': 'str',
        'storage_files': 'list[StorageFile]',
        'discover_storage_files': 'bool'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'partition_value': 'partitionValue',
        'sub_partition_values': 'subPartitionValues',
        'business_object_data_version': 'businessObjectDataVersion',
        'storage_name': 'storageName',
        'storage_files': 'storageFiles',
        'discover_storage_files': 'discoverStorageFiles'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, partition_value=None, sub_partition_values=None, business_object_data_version=None, storage_name=None, storage_files=None, discover_storage_files=None):  # noqa: E501
        """BusinessObjectDataStorageFilesCreateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._partition_value = None
        self._sub_partition_values = None
        self._business_object_data_version = None
        self._storage_name = None
        self._storage_files = None
        self._discover_storage_files = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        self.partition_value = partition_value
        if sub_partition_values is not None:
            self.sub_partition_values = sub_partition_values
        if business_object_data_version is not None:
            self.business_object_data_version = business_object_data_version
        self.storage_name = storage_name
        if storage_files is not None:
            self.storage_files = storage_files
        if discover_storage_files is not None:
            self.discover_storage_files = discover_storage_files

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The namespace of the business object data  # noqa: E501

        :return: The namespace of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectDataStorageFilesCreateRequest.

        The namespace of the business object data  # noqa: E501

        :param namespace: The namespace of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The definition name of the business object data  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectDataStorageFilesCreateRequest.

        The definition name of the business object data  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The format usage of the business object data  # noqa: E501

        :return: The business_object_format_usage of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectDataStorageFilesCreateRequest.

        The format usage of the business object data  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The format file type of the business object data  # noqa: E501

        :return: The business_object_format_file_type of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectDataStorageFilesCreateRequest.

        The format file type of the business object data  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The format version of the business object data  # noqa: E501

        :return: The business_object_format_version of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectDataStorageFilesCreateRequest.

        The format version of the business object data  # noqa: E501

        :param business_object_format_version: The business_object_format_version of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def partition_value(self):
        """Gets the partition_value of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The the primary partition value of the business object data  # noqa: E501

        :return: The partition_value of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._partition_value

    @partition_value.setter
    def partition_value(self, partition_value):
        """Sets the partition_value of this BusinessObjectDataStorageFilesCreateRequest.

        The the primary partition value of the business object data  # noqa: E501

        :param partition_value: The partition_value of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: str
        """
        if partition_value is None:
            raise ValueError("Invalid value for `partition_value`, must not be `None`")  # noqa: E501

        self._partition_value = partition_value

    @property
    def sub_partition_values(self):
        """Gets the sub_partition_values of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The subpartition values of the business object data  # noqa: E501

        :return: The sub_partition_values of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._sub_partition_values

    @sub_partition_values.setter
    def sub_partition_values(self, sub_partition_values):
        """Sets the sub_partition_values of this BusinessObjectDataStorageFilesCreateRequest.

        The subpartition values of the business object data  # noqa: E501

        :param sub_partition_values: The sub_partition_values of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: list[str]
        """

        self._sub_partition_values = sub_partition_values

    @property
    def business_object_data_version(self):
        """Gets the business_object_data_version of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The version of the business object data  # noqa: E501

        :return: The business_object_data_version of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_data_version

    @business_object_data_version.setter
    def business_object_data_version(self, business_object_data_version):
        """Sets the business_object_data_version of this BusinessObjectDataStorageFilesCreateRequest.

        The version of the business object data  # noqa: E501

        :param business_object_data_version: The business_object_data_version of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: int
        """

        self._business_object_data_version = business_object_data_version

    @property
    def storage_name(self):
        """Gets the storage_name of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The name of the storage                  # noqa: E501

        :return: The storage_name of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this BusinessObjectDataStorageFilesCreateRequest.

        The name of the storage                  # noqa: E501

        :param storage_name: The storage_name of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: str
        """
        if storage_name is None:
            raise ValueError("Invalid value for `storage_name`, must not be `None`")  # noqa: E501

        self._storage_name = storage_name

    @property
    def storage_files(self):
        """Gets the storage_files of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        The list of storage files to be added. Storage files are required, unless discovery of storage files is enabled. In that case,                   the storage                   files are not allowed to be specified                  # noqa: E501

        :return: The storage_files of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: list[StorageFile]
        """
        return self._storage_files

    @storage_files.setter
    def storage_files(self, storage_files):
        """Sets the storage_files of this BusinessObjectDataStorageFilesCreateRequest.

        The list of storage files to be added. Storage files are required, unless discovery of storage files is enabled. In that case,                   the storage                   files are not allowed to be specified                  # noqa: E501

        :param storage_files: The storage_files of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: list[StorageFile]
        """

        self._storage_files = storage_files

    @property
    def discover_storage_files(self):
        """Gets the discover_storage_files of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501

        If true, enables the auto-discovery of all storage files in the relative S3 storage under the relative storage directory                  # noqa: E501

        :return: The discover_storage_files of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._discover_storage_files

    @discover_storage_files.setter
    def discover_storage_files(self, discover_storage_files):
        """Sets the discover_storage_files of this BusinessObjectDataStorageFilesCreateRequest.

        If true, enables the auto-discovery of all storage files in the relative S3 storage under the relative storage directory                  # noqa: E501

        :param discover_storage_files: The discover_storage_files of this BusinessObjectDataStorageFilesCreateRequest.  # noqa: E501
        :type: bool
        """

        self._discover_storage_files = discover_storage_files

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDataStorageFilesCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class StorageUnitNotificationFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'storage_name': 'str',
        'new_storage_unit_status': 'str',
        'old_storage_unit_status': 'str'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'storage_name': 'storageName',
        'new_storage_unit_status': 'newStorageUnitStatus',
        'old_storage_unit_status': 'oldStorageUnitStatus'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, storage_name=None, new_storage_unit_status=None, old_storage_unit_status=None):  # noqa: E501
        """StorageUnitNotificationFilter - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._storage_name = None
        self._new_storage_unit_status = None
        self._old_storage_unit_status = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        if business_object_format_usage is not None:
            self.business_object_format_usage = business_object_format_usage
        if business_object_format_file_type is not None:
            self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        self.storage_name = storage_name
        if new_storage_unit_status is not None:
            self.new_storage_unit_status = new_storage_unit_status
        if old_storage_unit_status is not None:
            self.old_storage_unit_status = old_storage_unit_status

    @property
    def namespace(self):
        """Gets the namespace of this StorageUnitNotificationFilter.  # noqa: E501

        The namespace of the business object definition  # noqa: E501

        :return: The namespace of this StorageUnitNotificationFilter.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this StorageUnitNotificationFilter.

        The namespace of the business object definition  # noqa: E501

        :param namespace: The namespace of this StorageUnitNotificationFilter.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this StorageUnitNotificationFilter.  # noqa: E501

        The business object definition name  # noqa: E501

        :return: The business_object_definition_name of this StorageUnitNotificationFilter.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this StorageUnitNotificationFilter.

        The business object definition name  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this StorageUnitNotificationFilter.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this StorageUnitNotificationFilter.  # noqa: E501

        The business object format usage  # noqa: E501

        :return: The business_object_format_usage of this StorageUnitNotificationFilter.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this StorageUnitNotificationFilter.

        The business object format usage  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this StorageUnitNotificationFilter.  # noqa: E501
        :type: str
        """

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this StorageUnitNotificationFilter.  # noqa: E501

        The business object format file type  # noqa: E501

        :return: The business_object_format_file_type of this StorageUnitNotificationFilter.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this StorageUnitNotificationFilter.

        The business object format file type  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this StorageUnitNotificationFilter.  # noqa: E501
        :type: str
        """

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this StorageUnitNotificationFilter.  # noqa: E501

        The business object format version  # noqa: E501

        :return: The business_object_format_version of this StorageUnitNotificationFilter.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this StorageUnitNotificationFilter.

        The business object format version  # noqa: E501

        :param business_object_format_version: The business_object_format_version of this StorageUnitNotificationFilter.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def storage_name(self):
        """Gets the storage_name of this StorageUnitNotificationFilter.  # noqa: E501

        The storage name  # noqa: E501

        :return: The storage_name of this StorageUnitNotificationFilter.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this StorageUnitNotificationFilter.

        The storage name  # noqa: E501

        :param storage_name: The storage_name of this StorageUnitNotificationFilter.  # noqa: E501
        :type: str
        """
        if storage_name is None:
            raise ValueError("Invalid value for `storage_name`, must not be `None`")  # noqa: E501

        self._storage_name = storage_name

    @property
    def new_storage_unit_status(self):
        """Gets the new_storage_unit_status of this StorageUnitNotificationFilter.  # noqa: E501

        The new storage unit status. One of the following values: ENABLED, DISABLED, ARCHIVING, or RESTORING  # noqa: E501

        :return: The new_storage_unit_status of this StorageUnitNotificationFilter.  # noqa: E501
        :rtype: str
        """
        return self._new_storage_unit_status

    @new_storage_unit_status.setter
    def new_storage_unit_status(self, new_storage_unit_status):
        """Sets the new_storage_unit_status of this StorageUnitNotificationFilter.

        The new storage unit status. One of the following values: ENABLED, DISABLED, ARCHIVING, or RESTORING  # noqa: E501

        :param new_storage_unit_status: The new_storage_unit_status of this StorageUnitNotificationFilter.  # noqa: E501
        :type: str
        """

        self._new_storage_unit_status = new_storage_unit_status

    @property
    def old_storage_unit_status(self):
        """Gets the old_storage_unit_status of this StorageUnitNotificationFilter.  # noqa: E501

        The old storage unit status. One of the following values: ENABLED, DISABLED, ARCHIVING, or RESTORING  # noqa: E501

        :return: The old_storage_unit_status of this StorageUnitNotificationFilter.  # noqa: E501
        :rtype: str
        """
        return self._old_storage_unit_status

    @old_storage_unit_status.setter
    def old_storage_unit_status(self, old_storage_unit_status):
        """Sets the old_storage_unit_status of this StorageUnitNotificationFilter.

        The old storage unit status. One of the following values: ENABLED, DISABLED, ARCHIVING, or RESTORING  # noqa: E501

        :param old_storage_unit_status: The old_storage_unit_status of this StorageUnitNotificationFilter.  # noqa: E501
        :type: str
        """

        self._old_storage_unit_status = old_storage_unit_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageUnitNotificationFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectFormatDdlRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'output_format': 'str',
        'table_name': 'str',
        'custom_ddl_name': 'str',
        'include_drop_table_statement': 'bool',
        'include_if_not_exists_option': 'bool',
        'replace_columns': 'bool'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'output_format': 'outputFormat',
        'table_name': 'tableName',
        'custom_ddl_name': 'customDdlName',
        'include_drop_table_statement': 'includeDropTableStatement',
        'include_if_not_exists_option': 'includeIfNotExistsOption',
        'replace_columns': 'replaceColumns'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, output_format=None, table_name=None, custom_ddl_name=None, include_drop_table_statement=None, include_if_not_exists_option=None, replace_columns=None):  # noqa: E501
        """BusinessObjectFormatDdlRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._output_format = None
        self._table_name = None
        self._custom_ddl_name = None
        self._include_drop_table_statement = None
        self._include_if_not_exists_option = None
        self._replace_columns = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        self.output_format = output_format
        self.table_name = table_name
        if custom_ddl_name is not None:
            self.custom_ddl_name = custom_ddl_name
        if include_drop_table_statement is not None:
            self.include_drop_table_statement = include_drop_table_statement
        if include_if_not_exists_option is not None:
            self.include_if_not_exists_option = include_if_not_exists_option
        if replace_columns is not None:
            self.replace_columns = replace_columns

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectFormatDdlRequest.  # noqa: E501

        The Namespace to which a Business Object Format is related  # noqa: E501

        :return: The namespace of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectFormatDdlRequest.

        The Namespace to which a Business Object Format is related  # noqa: E501

        :param namespace: The namespace of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectFormatDdlRequest.  # noqa: E501

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectFormatDdlRequest.

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectFormatDdlRequest.  # noqa: E501

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :return: The business_object_format_usage of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectFormatDdlRequest.

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectFormatDdlRequest.  # noqa: E501

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :return: The business_object_format_file_type of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectFormatDdlRequest.

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectFormatDdlRequest.  # noqa: E501

        The numeric version of a Business Object Format. If not supplied, the latest version will be used  # noqa: E501

        :return: The business_object_format_version of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectFormatDdlRequest.

        The numeric version of a Business Object Format. If not supplied, the latest version will be used  # noqa: E501

        :param business_object_format_version: The business_object_format_version of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def output_format(self):
        """Gets the output_format of this BusinessObjectFormatDdlRequest.  # noqa: E501

        The output format for the generated DDL. The only format currently supported is HIVE_13_DDL  # noqa: E501

        :return: The output_format of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._output_format

    @output_format.setter
    def output_format(self, output_format):
        """Sets the output_format of this BusinessObjectFormatDdlRequest.

        The output format for the generated DDL. The only format currently supported is HIVE_13_DDL  # noqa: E501

        :param output_format: The output_format of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: str
        """
        if output_format is None:
            raise ValueError("Invalid value for `output_format`, must not be `None`")  # noqa: E501
        allowed_values = ["HIVE_13_DDL"]  # noqa: E501
        if output_format not in allowed_values:
            raise ValueError(
                "Invalid value for `output_format` ({0}), must be one of {1}"  # noqa: E501
                .format(output_format, allowed_values)
            )

        self._output_format = output_format

    @property
    def table_name(self):
        """Gets the table_name of this BusinessObjectFormatDdlRequest.  # noqa: E501

        The table name to be used in the generated DDL  # noqa: E501

        :return: The table_name of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this BusinessObjectFormatDdlRequest.

        The table name to be used in the generated DDL  # noqa: E501

        :param table_name: The table_name of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: str
        """
        if table_name is None:
            raise ValueError("Invalid value for `table_name`, must not be `None`")  # noqa: E501

        self._table_name = table_name

    @property
    def custom_ddl_name(self):
        """Gets the custom_ddl_name of this BusinessObjectFormatDdlRequest.  # noqa: E501

        The name of the Custom DDL. When Custom DDL name is specified, the Custom DDL which had previously been stored Business Object                   Format is returned instead of generated DDL. Must not be specified when replaceColumns is true                  # noqa: E501

        :return: The custom_ddl_name of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._custom_ddl_name

    @custom_ddl_name.setter
    def custom_ddl_name(self, custom_ddl_name):
        """Sets the custom_ddl_name of this BusinessObjectFormatDdlRequest.

        The name of the Custom DDL. When Custom DDL name is specified, the Custom DDL which had previously been stored Business Object                   Format is returned instead of generated DDL. Must not be specified when replaceColumns is true                  # noqa: E501

        :param custom_ddl_name: The custom_ddl_name of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: str
        """

        self._custom_ddl_name = custom_ddl_name

    @property
    def include_drop_table_statement(self):
        """Gets the include_drop_table_statement of this BusinessObjectFormatDdlRequest.  # noqa: E501

        If true, drop table statement for existing table will be added to the generated DDL. Must not be specified when replaceColumns                   is true.                  # noqa: E501

        :return: The include_drop_table_statement of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_drop_table_statement

    @include_drop_table_statement.setter
    def include_drop_table_statement(self, include_drop_table_statement):
        """Sets the include_drop_table_statement of this BusinessObjectFormatDdlRequest.

        If true, drop table statement for existing table will be added to the generated DDL. Must not be specified when replaceColumns                   is true.                  # noqa: E501

        :param include_drop_table_statement: The include_drop_table_statement of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: bool
        """

        self._include_drop_table_statement = include_drop_table_statement

    @property
    def include_if_not_exists_option(self):
        """Gets the include_if_not_exists_option of this BusinessObjectFormatDdlRequest.  # noqa: E501

        If true, IF NOT EXISTS option will be added to the CREATE TABLE ... statement in the generrated DDL. Please note that this                   parameter value has no effect on the relative CREATE TABLE ... statement, if generated DDL uses custom DDL. Must not be specified when                   replaceColumns is true.                  # noqa: E501

        :return: The include_if_not_exists_option of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_if_not_exists_option

    @include_if_not_exists_option.setter
    def include_if_not_exists_option(self, include_if_not_exists_option):
        """Sets the include_if_not_exists_option of this BusinessObjectFormatDdlRequest.

        If true, IF NOT EXISTS option will be added to the CREATE TABLE ... statement in the generrated DDL. Please note that this                   parameter value has no effect on the relative CREATE TABLE ... statement, if generated DDL uses custom DDL. Must not be specified when                   replaceColumns is true.                  # noqa: E501

        :param include_if_not_exists_option: The include_if_not_exists_option of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: bool
        """

        self._include_if_not_exists_option = include_if_not_exists_option

    @property
    def replace_columns(self):
        """Gets the replace_columns of this BusinessObjectFormatDdlRequest.  # noqa: E501

        If true, an ALTER TABLE ... REPLACE COLUMNS will be generated  # noqa: E501

        :return: The replace_columns of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._replace_columns

    @replace_columns.setter
    def replace_columns(self, replace_columns):
        """Sets the replace_columns of this BusinessObjectFormatDdlRequest.

        If true, an ALTER TABLE ... REPLACE COLUMNS will be generated  # noqa: E501

        :param replace_columns: The replace_columns of this BusinessObjectFormatDdlRequest.  # noqa: E501
        :type: bool
        """

        self._replace_columns = replace_columns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectFormatDdlRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class BusinessObjectFormatApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def business_object_format_create_business_object_format(self, business_object_format_create_request, **kwargs):  # noqa: E501
        """createBusinessObjectFormat  # noqa: E501

        Creates a new business object format. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_create_business_object_format(business_object_format_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectFormatCreateRequest business_object_format_create_request: the information needed to create the business object format. (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_create_business_object_format_with_http_info(business_object_format_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_create_business_object_format_with_http_info(business_object_format_create_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_create_business_object_format_with_http_info(self, business_object_format_create_request, **kwargs):  # noqa: E501
        """createBusinessObjectFormat  # noqa: E501

        Creates a new business object format. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_create_business_object_format_with_http_info(business_object_format_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectFormatCreateRequest business_object_format_create_request: the information needed to create the business object format. (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_format_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_create_business_object_format" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_format_create_request' is set
        if ('business_object_format_create_request' not in local_var_params or
                local_var_params['business_object_format_create_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_create_request` when calling `business_object_format_create_business_object_format`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_create_request' in local_var_params:
            body_params = local_var_params['business_object_format_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormats', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_delete_business_object_format(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, **kwargs):  # noqa: E501
        """deleteBusinessObjectFormat  # noqa: E501

        Deletes an existing business format. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_delete_business_object_format(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_delete_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_delete_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, **kwargs)  # noqa: E501
            return data

    def business_object_format_delete_business_object_format_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, **kwargs):  # noqa: E501
        """deleteBusinessObjectFormat  # noqa: E501

        Deletes an existing business format. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_delete_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_delete_business_object_format" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_delete_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_delete_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_delete_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_delete_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_version' is set
        if ('business_object_format_version' not in local_var_params or
                local_var_params['business_object_format_version'] is None):
            raise ValueError("Missing the required parameter `business_object_format_version` when calling `business_object_format_delete_business_object_format`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501
        if 'business_object_format_version' in local_var_params:
            path_params['businessObjectFormatVersion'] = local_var_params['business_object_format_version']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_generate_business_object_format_ddl(self, business_object_format_ddl_request, **kwargs):  # noqa: E501
        """generateBusinessObjectFormatDdl  # noqa: E501

        Retrieves the DDL to initialize the specified type of the database system (e.g. Hive) by creating a table for the requested business object format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_generate_business_object_format_ddl(business_object_format_ddl_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectFormatDdlRequest business_object_format_ddl_request: the business object data DDL request (required)
        :return: BusinessObjectFormatDdl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_generate_business_object_format_ddl_with_http_info(business_object_format_ddl_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_generate_business_object_format_ddl_with_http_info(business_object_format_ddl_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_generate_business_object_format_ddl_with_http_info(self, business_object_format_ddl_request, **kwargs):  # noqa: E501
        """generateBusinessObjectFormatDdl  # noqa: E501

        Retrieves the DDL to initialize the specified type of the database system (e.g. Hive) by creating a table for the requested business object format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_generate_business_object_format_ddl_with_http_info(business_object_format_ddl_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectFormatDdlRequest business_object_format_ddl_request: the business object data DDL request (required)
        :return: BusinessObjectFormatDdl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_format_ddl_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_generate_business_object_format_ddl" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_format_ddl_request' is set
        if ('business_object_format_ddl_request' not in local_var_params or
                local_var_params['business_object_format_ddl_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_ddl_request` when calling `business_object_format_generate_business_object_format_ddl`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_ddl_request' in local_var_params:
            body_params = local_var_params['business_object_format_ddl_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormats/generateDdl', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormatDdl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_generate_business_object_format_ddl_collection(self, business_object_format_ddl_collection_request, **kwargs):  # noqa: E501
        """generateBusinessObjectFormatDdlCollection  # noqa: E501

        Retrieves the DDL to initialize the specified type of the database system (e.g. Hive) by creating tables for a collection of business object formats. <p>Requires READ permission on ALL namespaces</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_generate_business_object_format_ddl_collection(business_object_format_ddl_collection_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectFormatDdlCollectionRequest business_object_format_ddl_collection_request: the business object format DDL collection request (required)
        :return: BusinessObjectFormatDdlCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_generate_business_object_format_ddl_collection_with_http_info(business_object_format_ddl_collection_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_generate_business_object_format_ddl_collection_with_http_info(business_object_format_ddl_collection_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_generate_business_object_format_ddl_collection_with_http_info(self, business_object_format_ddl_collection_request, **kwargs):  # noqa: E501
        """generateBusinessObjectFormatDdlCollection  # noqa: E501

        Retrieves the DDL to initialize the specified type of the database system (e.g. Hive) by creating tables for a collection of business object formats. <p>Requires READ permission on ALL namespaces</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_generate_business_object_format_ddl_collection_with_http_info(business_object_format_ddl_collection_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectFormatDdlCollectionRequest business_object_format_ddl_collection_request: the business object format DDL collection request (required)
        :return: BusinessObjectFormatDdlCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_format_ddl_collection_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_generate_business_object_format_ddl_collection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_format_ddl_collection_request' is set
        if ('business_object_format_ddl_collection_request' not in local_var_params or
                local_var_params['business_object_format_ddl_collection_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_ddl_collection_request` when calling `business_object_format_generate_business_object_format_ddl_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_ddl_collection_request' in local_var_params:
            body_params = local_var_params['business_object_format_ddl_collection_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormats/generateDdlCollection', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormatDdlCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_get_business_object_format(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, **kwargs):  # noqa: E501
        """getBusinessObjectFormat  # noqa: E501

        Gets an existing business object format by alternate key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_get_business_object_format(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_get_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_get_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, **kwargs)  # noqa: E501
            return data

    def business_object_format_get_business_object_format_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, **kwargs):  # noqa: E501
        """getBusinessObjectFormat  # noqa: E501

        Gets an existing business object format by alternate key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_get_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_get_business_object_format" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_get_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_get_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_get_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_get_business_object_format`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501

        query_params = []
        if 'business_object_format_version' in local_var_params:
            query_params.append(('businessObjectFormatVersion', local_var_params['business_object_format_version']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_get_business_object_formats(self, namespace, business_object_definition_name, **kwargs):  # noqa: E501
        """getBusinessObjectFormats  # noqa: E501

        Gets a list of business object formats for the specified business object definition name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_get_business_object_formats(namespace, business_object_definition_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param bool latest_business_object_format_version:
        :return: BusinessObjectFormatKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_get_business_object_formats_with_http_info(namespace, business_object_definition_name, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_get_business_object_formats_with_http_info(namespace, business_object_definition_name, **kwargs)  # noqa: E501
            return data

    def business_object_format_get_business_object_formats_with_http_info(self, namespace, business_object_definition_name, **kwargs):  # noqa: E501
        """getBusinessObjectFormats  # noqa: E501

        Gets a list of business object formats for the specified business object definition name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_get_business_object_formats_with_http_info(namespace, business_object_definition_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param bool latest_business_object_format_version:
        :return: BusinessObjectFormatKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'latest_business_object_format_version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_get_business_object_formats" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_get_business_object_formats`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_get_business_object_formats`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501

        query_params = []
        if 'latest_business_object_format_version' in local_var_params:
            query_params.append(('latestBusinessObjectFormatVersion', local_var_params['latest_business_object_format_version']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormatKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_get_business_object_formats_with_filters(self, namespace, business_object_definition_name, business_object_format_usage, **kwargs):  # noqa: E501
        """getBusinessObjectFormatsWithFilters  # noqa: E501

        Gets a list of business object formats for the specified business object definition name and business object format usage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_get_business_object_formats_with_filters(namespace, business_object_definition_name, business_object_format_usage, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param bool latest_business_object_format_version: latest business object format version
        :return: BusinessObjectFormatKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_get_business_object_formats_with_filters_with_http_info(namespace, business_object_definition_name, business_object_format_usage, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_get_business_object_formats_with_filters_with_http_info(namespace, business_object_definition_name, business_object_format_usage, **kwargs)  # noqa: E501
            return data

    def business_object_format_get_business_object_formats_with_filters_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, **kwargs):  # noqa: E501
        """getBusinessObjectFormatsWithFilters  # noqa: E501

        Gets a list of business object formats for the specified business object definition name and business object format usage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_get_business_object_formats_with_filters_with_http_info(namespace, business_object_definition_name, business_object_format_usage, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param bool latest_business_object_format_version: latest business object format version
        :return: BusinessObjectFormatKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'latest_business_object_format_version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_get_business_object_formats_with_filters" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_get_business_object_formats_with_filters`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_get_business_object_formats_with_filters`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_get_business_object_formats_with_filters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501

        query_params = []
        if 'latest_business_object_format_version' in local_var_params:
            query_params.append(('latestBusinessObjectFormatVersion', local_var_params['latest_business_object_format_version']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormatKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_update_business_object_format(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormat  # noqa: E501

        Updates an existing business object format by alternate key. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version (required)
        :param BusinessObjectFormatUpdateRequest business_object_format_update_request: the information needed to update the business object format (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_update_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_update_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_update_business_object_format_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormat  # noqa: E501

        Updates an existing business object format by alternate key. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version (required)
        :param BusinessObjectFormatUpdateRequest business_object_format_update_request: the information needed to update the business object format (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_version', 'business_object_format_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_update_business_object_format" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_update_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_update_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_update_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_update_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_version' is set
        if ('business_object_format_version' not in local_var_params or
                local_var_params['business_object_format_version'] is None):
            raise ValueError("Missing the required parameter `business_object_format_version` when calling `business_object_format_update_business_object_format`")  # noqa: E501
        # verify the required parameter 'business_object_format_update_request' is set
        if ('business_object_format_update_request' not in local_var_params or
                local_var_params['business_object_format_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_update_request` when calling `business_object_format_update_business_object_format`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501
        if 'business_object_format_version' in local_var_params:
            path_params['businessObjectFormatVersion'] = local_var_params['business_object_format_version']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_update_request' in local_var_params:
            body_params = local_var_params['business_object_format_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_update_business_object_format_attribute_definitions(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attribute_definitions_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatAttributeDefinitions  # noqa: E501

        Replaces the list of attribute definitions for an existing business object format based on the specified usage, file type, version and a business object definition. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_attribute_definitions(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attribute_definitions_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version (required)
        :param BusinessObjectFormatAttributeDefinitionsUpdateRequest business_object_format_attribute_definitions_update_request: the information needed to update the business object format attribute definitions (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_update_business_object_format_attribute_definitions_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attribute_definitions_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_update_business_object_format_attribute_definitions_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attribute_definitions_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_update_business_object_format_attribute_definitions_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attribute_definitions_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatAttributeDefinitions  # noqa: E501

        Replaces the list of attribute definitions for an existing business object format based on the specified usage, file type, version and a business object definition. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_attribute_definitions_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attribute_definitions_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version (required)
        :param BusinessObjectFormatAttributeDefinitionsUpdateRequest business_object_format_attribute_definitions_update_request: the information needed to update the business object format attribute definitions (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_version', 'business_object_format_attribute_definitions_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_update_business_object_format_attribute_definitions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_update_business_object_format_attribute_definitions`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_update_business_object_format_attribute_definitions`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_update_business_object_format_attribute_definitions`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_update_business_object_format_attribute_definitions`")  # noqa: E501
        # verify the required parameter 'business_object_format_version' is set
        if ('business_object_format_version' not in local_var_params or
                local_var_params['business_object_format_version'] is None):
            raise ValueError("Missing the required parameter `business_object_format_version` when calling `business_object_format_update_business_object_format_attribute_definitions`")  # noqa: E501
        # verify the required parameter 'business_object_format_attribute_definitions_update_request' is set
        if ('business_object_format_attribute_definitions_update_request' not in local_var_params or
                local_var_params['business_object_format_attribute_definitions_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_attribute_definitions_update_request` when calling `business_object_format_update_business_object_format_attribute_definitions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501
        if 'business_object_format_version' in local_var_params:
            path_params['businessObjectFormatVersion'] = local_var_params['business_object_format_version']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_attribute_definitions_update_request' in local_var_params:
            body_params = local_var_params['business_object_format_attribute_definitions_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormatAttributeDefinitions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_update_business_object_format_attributes(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attributes_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatAttributes  # noqa: E501

        Updates an existing business object format attributes by alternate key. <p>Requires WRITE permission on namespace</p> <p> This endpoint replaces the entire list of attributes on the business object format with the contents of the request. Observe this example: <ol> <li>Three attributes present on the existing business object format.</li> <li>This endpoint is called with a single attribute in the request with an updated value.</li> <li>After this operation the business object format will have only one attribute – which is probably not the desired outcome.</li> <li>Instead, supply all existing attributes and provide updated values and additional attributes as needed. The only case when an existing attribute should be left out is to remove the attribute.</li> </ol> </p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_attributes(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attributes_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version (required)
        :param BusinessObjectFormatAttributesUpdateRequest business_object_format_attributes_update_request: the information needed to update the business object format attributes (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_update_business_object_format_attributes_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attributes_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_update_business_object_format_attributes_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attributes_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_update_business_object_format_attributes_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attributes_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatAttributes  # noqa: E501

        Updates an existing business object format attributes by alternate key. <p>Requires WRITE permission on namespace</p> <p> This endpoint replaces the entire list of attributes on the business object format with the contents of the request. Observe this example: <ol> <li>Three attributes present on the existing business object format.</li> <li>This endpoint is called with a single attribute in the request with an updated value.</li> <li>After this operation the business object format will have only one attribute – which is probably not the desired outcome.</li> <li>Instead, supply all existing attributes and provide updated values and additional attributes as needed. The only case when an existing attribute should be left out is to remove the attribute.</li> </ol> </p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_attributes_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_version, business_object_format_attributes_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param int business_object_format_version: the business object format version (required)
        :param BusinessObjectFormatAttributesUpdateRequest business_object_format_attributes_update_request: the information needed to update the business object format attributes (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_version', 'business_object_format_attributes_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_update_business_object_format_attributes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_update_business_object_format_attributes`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_update_business_object_format_attributes`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_update_business_object_format_attributes`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_update_business_object_format_attributes`")  # noqa: E501
        # verify the required parameter 'business_object_format_version' is set
        if ('business_object_format_version' not in local_var_params or
                local_var_params['business_object_format_version'] is None):
            raise ValueError("Missing the required parameter `business_object_format_version` when calling `business_object_format_update_business_object_format_attributes`")  # noqa: E501
        # verify the required parameter 'business_object_format_attributes_update_request' is set
        if ('business_object_format_attributes_update_request' not in local_var_params or
                local_var_params['business_object_format_attributes_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_attributes_update_request` when calling `business_object_format_update_business_object_format_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501
        if 'business_object_format_version' in local_var_params:
            path_params['businessObjectFormatVersion'] = local_var_params['business_object_format_version']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_attributes_update_request' in local_var_params:
            body_params = local_var_params['business_object_format_attributes_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormatAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_update_business_object_format_legal_hold(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_legal_hold_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatLegalHold  # noqa: E501

        Updates legal hold status for an existing business object format by alternate key without business object format version. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_legal_hold(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_legal_hold_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatLegalHoldUpdateRequest business_object_format_legal_hold_update_request: the information needed to update the business object format legal hold (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_update_business_object_format_legal_hold_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_legal_hold_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_update_business_object_format_legal_hold_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_legal_hold_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_update_business_object_format_legal_hold_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_legal_hold_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatLegalHold  # noqa: E501

        Updates legal hold status for an existing business object format by alternate key without business object format version. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_legal_hold_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_legal_hold_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatLegalHoldUpdateRequest business_object_format_legal_hold_update_request: the information needed to update the business object format legal hold (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_legal_hold_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_update_business_object_format_legal_hold" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_update_business_object_format_legal_hold`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_update_business_object_format_legal_hold`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_update_business_object_format_legal_hold`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_update_business_object_format_legal_hold`")  # noqa: E501
        # verify the required parameter 'business_object_format_legal_hold_update_request' is set
        if ('business_object_format_legal_hold_update_request' not in local_var_params or
                local_var_params['business_object_format_legal_hold_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_legal_hold_update_request` when calling `business_object_format_update_business_object_format_legal_hold`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_legal_hold_update_request' in local_var_params:
            body_params = local_var_params['business_object_format_legal_hold_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormatLegalHold/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_update_business_object_format_parents(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_parents_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatParents  # noqa: E501

        Updates an existing business object format parents by alternate key. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_parents(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_parents_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatParentsUpdateRequest business_object_format_parents_update_request: the information needed to update the business object format (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_update_business_object_format_parents_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_parents_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_update_business_object_format_parents_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_parents_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_update_business_object_format_parents_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_parents_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatParents  # noqa: E501

        Updates an existing business object format parents by alternate key. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_parents_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_parents_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatParentsUpdateRequest business_object_format_parents_update_request: the information needed to update the business object format (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_parents_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_update_business_object_format_parents" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_update_business_object_format_parents`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_update_business_object_format_parents`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_update_business_object_format_parents`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_update_business_object_format_parents`")  # noqa: E501
        # verify the required parameter 'business_object_format_parents_update_request' is set
        if ('business_object_format_parents_update_request' not in local_var_params or
                local_var_params['business_object_format_parents_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_parents_update_request` when calling `business_object_format_update_business_object_format_parents`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_parents_update_request' in local_var_params:
            body_params = local_var_params['business_object_format_parents_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormatParents/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_update_business_object_format_record_flag(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_record_flag_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatRecordFlag  # noqa: E501

        Updates or resets record flag for an existing business object format by alternate key without business object format version. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_record_flag(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_record_flag_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatRecordFlagUpdateRequest business_object_format_record_flag_update_request: the information needed to update the business object format legal hold (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_update_business_object_format_record_flag_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_record_flag_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_update_business_object_format_record_flag_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_record_flag_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_update_business_object_format_record_flag_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_record_flag_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatRecordFlag  # noqa: E501

        Updates or resets record flag for an existing business object format by alternate key without business object format version. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_record_flag_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_record_flag_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatRecordFlagUpdateRequest business_object_format_record_flag_update_request: the information needed to update the business object format legal hold (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_record_flag_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_update_business_object_format_record_flag" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_update_business_object_format_record_flag`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_update_business_object_format_record_flag`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_update_business_object_format_record_flag`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_update_business_object_format_record_flag`")  # noqa: E501
        # verify the required parameter 'business_object_format_record_flag_update_request' is set
        if ('business_object_format_record_flag_update_request' not in local_var_params or
                local_var_params['business_object_format_record_flag_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_record_flag_update_request` when calling `business_object_format_update_business_object_format_record_flag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_record_flag_update_request' in local_var_params:
            body_params = local_var_params['business_object_format_record_flag_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormatRecordFlag/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_update_business_object_format_retention_information(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_retention_information_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatRetentionInformation  # noqa: E501

        Updates an existing business object format retention information by alternate key. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_retention_information(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_retention_information_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatRetentionInformationUpdateRequest business_object_format_retention_information_update_request: the information needed to update the business object format retention information (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_update_business_object_format_retention_information_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_retention_information_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_update_business_object_format_retention_information_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_retention_information_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_update_business_object_format_retention_information_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_retention_information_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatRetentionInformation  # noqa: E501

        Updates an existing business object format retention information by alternate key. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_retention_information_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_retention_information_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatRetentionInformationUpdateRequest business_object_format_retention_information_update_request: the information needed to update the business object format retention information (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_retention_information_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_update_business_object_format_retention_information" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_update_business_object_format_retention_information`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_update_business_object_format_retention_information`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_update_business_object_format_retention_information`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_update_business_object_format_retention_information`")  # noqa: E501
        # verify the required parameter 'business_object_format_retention_information_update_request' is set
        if ('business_object_format_retention_information_update_request' not in local_var_params or
                local_var_params['business_object_format_retention_information_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_retention_information_update_request` when calling `business_object_format_update_business_object_format_retention_information`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_retention_information_update_request' in local_var_params:
            body_params = local_var_params['business_object_format_retention_information_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormatRetentionInformation/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_format_update_business_object_format_schema_backwards_compatible_changes(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_schema_backwards_compatibility_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatSchemaBackwardsCompatibleChanges  # noqa: E501

        Updates an existing Business Object Format to allow non-backwards compatibility changes to the format schema based on the 'allowNonBackwardsCompatibleChanges' flag. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_schema_backwards_compatible_changes(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_schema_backwards_compatibility_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatSchemaBackwardsCompatibilityUpdateRequest business_object_format_schema_backwards_compatibility_update_request: the information needed to update the business object format to allow non-backwards compatibility changes to the format schema (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_update_business_object_format_schema_backwards_compatible_changes_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_schema_backwards_compatibility_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_update_business_object_format_schema_backwards_compatible_changes_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_schema_backwards_compatibility_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_format_update_business_object_format_schema_backwards_compatible_changes_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_schema_backwards_compatibility_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectFormatSchemaBackwardsCompatibleChanges  # noqa: E501

        Updates an existing Business Object Format to allow non-backwards compatibility changes to the format schema based on the 'allowNonBackwardsCompatibleChanges' flag. <p>Requires WRITE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_update_business_object_format_schema_backwards_compatible_changes_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, business_object_format_schema_backwards_compatibility_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace code (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param BusinessObjectFormatSchemaBackwardsCompatibilityUpdateRequest business_object_format_schema_backwards_compatibility_update_request: the information needed to update the business object format to allow non-backwards compatibility changes to the format schema (required)
        :return: BusinessObjectFormat
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'business_object_format_schema_backwards_compatibility_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_update_business_object_format_schema_backwards_compatible_changes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_update_business_object_format_schema_backwards_compatible_changes`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_update_business_object_format_schema_backwards_compatible_changes`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_update_business_object_format_schema_backwards_compatible_changes`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_update_business_object_format_schema_backwards_compatible_changes`")  # noqa: E501
        # verify the required parameter 'business_object_format_schema_backwards_compatibility_update_request' is set
        if ('business_object_format_schema_backwards_compatibility_update_request' not in local_var_params or
                local_var_params['business_object_format_schema_backwards_compatibility_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_format_schema_backwards_compatibility_update_request` when calling `business_object_format_update_business_object_format_schema_backwards_compatible_changes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_format_schema_backwards_compatibility_update_request' in local_var_params:
            body_params = local_var_params['business_object_format_schema_backwards_compatibility_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormatSchemaBackwardsCompatibility/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormat',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class TagCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tag_key': 'TagKey',
        'display_name': 'str',
        'search_score_multiplier': 'float',
        'description': 'str',
        'parent_tag_key': 'TagKey'
    }

    attribute_map = {
        'tag_key': 'tagKey',
        'display_name': 'displayName',
        'search_score_multiplier': 'searchScoreMultiplier',
        'description': 'description',
        'parent_tag_key': 'parentTagKey'
    }

    def __init__(self, tag_key=None, display_name=None, search_score_multiplier=None, description=None, parent_tag_key=None):  # noqa: E501
        """TagCreateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._tag_key = None
        self._display_name = None
        self._search_score_multiplier = None
        self._description = None
        self._parent_tag_key = None
        self.discriminator = None

        self.tag_key = tag_key
        self.display_name = display_name
        if search_score_multiplier is not None:
            self.search_score_multiplier = search_score_multiplier
        if description is not None:
            self.description = description
        if parent_tag_key is not None:
            self.parent_tag_key = parent_tag_key

    @property
    def tag_key(self):
        """Gets the tag_key of this TagCreateRequest.  # noqa: E501


        :return: The tag_key of this TagCreateRequest.  # noqa: E501
        :rtype: TagKey
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this TagCreateRequest.


        :param tag_key: The tag_key of this TagCreateRequest.  # noqa: E501
        :type: TagKey
        """
        if tag_key is None:
            raise ValueError("Invalid value for `tag_key`, must not be `None`")  # noqa: E501

        self._tag_key = tag_key

    @property
    def display_name(self):
        """Gets the display_name of this TagCreateRequest.  # noqa: E501

        The tag's name in plain text for human readability  # noqa: E501

        :return: The display_name of this TagCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this TagCreateRequest.

        The tag's name in plain text for human readability  # noqa: E501

        :param display_name: The display_name of this TagCreateRequest.  # noqa: E501
        :type: str
        """
        if display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def search_score_multiplier(self):
        """Gets the search_score_multiplier of this TagCreateRequest.  # noqa: E501

        An optional tag's search score multiplier. Search score multiplier is numeric and can be a decimal  # noqa: E501

        :return: The search_score_multiplier of this TagCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._search_score_multiplier

    @search_score_multiplier.setter
    def search_score_multiplier(self, search_score_multiplier):
        """Sets the search_score_multiplier of this TagCreateRequest.

        An optional tag's search score multiplier. Search score multiplier is numeric and can be a decimal  # noqa: E501

        :param search_score_multiplier: The search_score_multiplier of this TagCreateRequest.  # noqa: E501
        :type: float
        """

        self._search_score_multiplier = search_score_multiplier

    @property
    def description(self):
        """Gets the description of this TagCreateRequest.  # noqa: E501

        An optional description  # noqa: E501

        :return: The description of this TagCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TagCreateRequest.

        An optional description  # noqa: E501

        :param description: The description of this TagCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def parent_tag_key(self):
        """Gets the parent_tag_key of this TagCreateRequest.  # noqa: E501


        :return: The parent_tag_key of this TagCreateRequest.  # noqa: E501
        :rtype: TagKey
        """
        return self._parent_tag_key

    @parent_tag_key.setter
    def parent_tag_key(self, parent_tag_key):
        """Sets the parent_tag_key of this TagCreateRequest.


        :param parent_tag_key: The parent_tag_key of this TagCreateRequest.  # noqa: E501
        :type: TagKey
        """

        self._parent_tag_key = parent_tag_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
